@@ -59,6 +59,7 @@ from octobot_tentacles_manager.api.updater import (
 from octobot_tentacles_manager.api.loader import (
     load_tentacles,
     reload_tentacle_info,
+    are_tentacles_up_to_date,
 )
 from octobot_tentacles_manager.api.inspector import (
     get_installed_tentacles_modules,
@@ -107,6 +108,7 @@ __all__ = [
     "update_tentacles",
     "load_tentacles",
     "reload_tentacle_info",
+    "are_tentacles_up_to_date",
     "get_installed_tentacles_modules",
     "get_tentacle_group",
     "get_tentacle_version",
