@@ -15,7 +15,6 @@
 #  License along with this library.
 import os
 import os.path as path
-import shutil
 
 import octobot_commons.logging as logging
 import octobot_commons.constants as commons_constants
@@ -197,14 +196,12 @@ class TentaclesSetupConfiguration:
             if tentacle_class_name in default_config[tentacle.tentacle_root_type]:
                 self.tentacles_activation[tentacle.tentacle_root_type][tentacle_class_name] = \
                     default_config[tentacle.tentacle_root_type][tentacle_class_name]
-            else:
-                # activate by default unless the sub type of this tentacle in among the sub types to be deactivated by
-                # default
-                self.tentacles_activation[tentacle.tentacle_root_type][tentacle_class_name] = \
-                    tentacle.get_simple_tentacle_type() not in self.DEFAULT_DEACTIVATABLE_TENTACLE_SUB_TYPES
-        else:
-            # if tentacle_type not in default config: activate by default
-            self.tentacles_activation[tentacle.tentacle_root_type][tentacle_class_name] = True
+                return
+
+        # activate by default unless the sub type of this tentacle in among the sub types to be deactivated by default
+        # or if tentacle_type not in default config: activate by default
+        self.tentacles_activation[tentacle.tentacle_root_type][tentacle_class_name] = \
+            tentacle.get_simple_tentacle_type() not in self.DEFAULT_DEACTIVATABLE_TENTACLE_SUB_TYPES
 
     def _filter_tentacle_activation(self, tentacles):
         tentacle_names = [tentacle_class_name
@@ -255,8 +252,6 @@ class TentaclesSetupConfiguration:
                                                               commons_constants.CONFIG_TENTACLES_FILE),
                                                     newly_installed_tentacles,
                                                     uninstalled_tentacles)
-        self._refresh_profile_tentacles_specific_config(path.join(profile_folder,
-                                                                  constants.TENTACLES_SPECIFIC_CONFIG_FOLDER))
 
     def _refresh_profile_tentacles_config_file(self, tentacles, tentacles_config_file,
                                                newly_installed_tentacles, uninstalled_tentacles):
@@ -291,17 +286,6 @@ class TentaclesSetupConfiguration:
             for element in to_remove:
                 element_names.pop(element, None)
 
-    def _refresh_profile_tentacles_specific_config(self, tentacles_specific_config_folder):
-        tentacles_config_path = path.join(path.split(self.config_path)[0],
-                                          constants.TENTACLES_SPECIFIC_CONFIG_FOLDER)
-        if not path.isdir(tentacles_specific_config_folder):
-            os.mkdir(tentacles_specific_config_folder)
-        profile_tentacles_configs = os.listdir(tentacles_specific_config_folder)
-        for tentacle_config in os.scandir(tentacles_config_path):
-            # add missing specific tentacles config
-            if tentacle_config.name not in profile_tentacles_configs:
-                shutil.copy(tentacle_config, path.join(tentacles_specific_config_folder, tentacle_config.name))
-
     def _ensure_installation_context(self):
         if not self.installation_context:
             self._fill_installation_context()
