@@ -27,7 +27,8 @@ from octobot_tentacles_manager.constants import TENTACLES_PATH, PYTHON_INIT_FILE
     TENTACLES_EVALUATOR_REALTIME_PATH, TENTACLE_METADATA, METADATA_VERSION, METADATA_ORIGIN_PACKAGE, \
     METADATA_TENTACLES, METADATA_TENTACLES_REQUIREMENTS, METADATA_DEV_MODE, TENTACLES_TRADING_PATH, CURRENT_DIR_PATH, \
     TENTACLES_TRADING_MODE_PATH, TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER, TENTACLES_SERVICES_PATH, \
-    TENTACLES_BACKTESTING_IMPORTERS_PATH, TENTACLES_BACKTESTING_PATH, TENTACLES_BACKTESTING_THIRD_LEVEL_EXCHANGES_PATH
+    TENTACLES_BACKTESTING_IMPORTERS_PATH, TENTACLES_BACKTESTING_PATH, TENTACLES_BACKTESTING_THIRD_LEVEL_EXCHANGES_PATH, \
+    ANY_PLATFORM_FILE_NAME
 
 # All test coroutines will be treated as marked.
 pytestmark = pytest.mark.asyncio
@@ -140,11 +141,17 @@ async def test_create_folder_tentacles_package_with_package_selector(install_ten
 
 async def test_create_zipped_tentacles_package(install_tentacles):
     tentacle_package = "tentacle_package.zip"
-    assert await create_tentacles_package(tentacle_package, output_dir=".") == 0
+    assert await create_tentacles_package(tentacle_package, output_dir=".", use_package_as_file_name=True) == 0
     assert path.exists(tentacle_package)
     assert not path.exists(TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER)
     remove(tentacle_package)
 
+    expected_file_name = f"{ANY_PLATFORM_FILE_NAME}.zip"
+    assert await create_tentacles_package(tentacle_package, output_dir=".", use_package_as_file_name=False) == 0
+    assert path.exists(expected_file_name)
+    assert not path.exists(TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER)
+    remove(expected_file_name)
+
 
 async def test_create_cythonized_tentacles_package(install_tentacles):
     speedup_cythonization()
@@ -191,7 +198,7 @@ async def test_create_all_tentacles_bundle_cleaned_not_zipped_but_cythonized(ins
     # test bundle metadata
     assert_directory_has_file_with_content(os.path.join(TEST_EXPORT_DIR, "generic_exchange_importer@1.2.0"),
                                            "metadata.yaml",
-                                           "author: DrakkarSoftware\nname: generic_exchange_importer\nrepository: Unknown repository location\ntype: tentacle\nversion: 1.2.0\n")
+                                           "author: DrakkarSoftware\ndescription: ''\nname: generic_exchange_importer\nrepository: Unknown repository location\nshort-name: generic_exchange_importer\ntags: []\ntype: tentacle\nversion: 1.2.0\n")
 
 
 async def test_create_all_tentacles_bundle_zipped_not_cleaned_and_zipped(install_tentacles):
@@ -199,7 +206,8 @@ async def test_create_all_tentacles_bundle_zipped_not_cleaned_and_zipped(install
                                              in_zip=True,
                                              cythonize=False,
                                              should_remove_artifacts_after_use=False,
-                                             should_zip_bundle=True) == 0
+                                             should_zip_bundle=True,
+                                             use_package_as_file_name=True) == 0
 
     # test not should_remove_artifacts_after_use
     assert os.path.isfile(os.path.join(TEST_EXPORT_DIR, "generic_exchange_importer.zip"))
@@ -215,7 +223,8 @@ async def test_create_all_tentacles_bundle_not_zipped_not_cleaned_and_zipped(ins
                                              in_zip=True,
                                              cythonize=False,
                                              should_remove_artifacts_after_use=False,
-                                             should_zip_bundle=False) == 0
+                                             should_zip_bundle=False,
+                                             use_package_as_file_name=True) == 0
 
     # test not should_remove_artifacts_after_use
     assert os.path.isfile(os.path.join(TEST_EXPORT_DIR, "generic_exchange_importer.zip"))
@@ -232,7 +241,8 @@ async def test_create_tentacles_package_in_previous_dir(install_tentacles):
     expected_file_path: str = "../test.zip"
     assert await create_tentacles_package(package_name=file_path,
                                           output_dir=CURRENT_DIR_PATH,
-                                          in_zip=True) == 0
+                                          in_zip=True,
+                                          use_package_as_file_name=True) == 0
     assert os.path.exists(expected_file_path)
     os.remove(expected_file_path)
 
@@ -240,7 +250,8 @@ async def test_create_tentacles_package_in_previous_dir(install_tentacles):
     file_path: str = "../test2.zip"
     expected_file_path: str = "test2.zip"  # output/../test2.zip
     assert await create_tentacles_package(package_name=file_path,
-                                          in_zip=True) == 0
+                                          in_zip=True,
+                                          use_package_as_file_name=True) == 0
     assert os.path.exists(expected_file_path)
     os.remove(expected_file_path)
 
